settings

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 27, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package settings provides Cobra commands for viewing and updating AdGuard Home rewrite settings across one or more instances.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand() *cobra.Command

NewCommand creates the rewrite settings command and registers its subcommands.

Returns:

  • *cobra.Command: The settings command.

Types

This section is empty.

Jump to