Documentation
¶
Overview ¶
Package settings provides Cobra commands for viewing and updating AdGuard Home rewrite settings across one or more instances.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommand ¶
NewCommand creates the rewrite settings command and registers its subcommands.
Returns:
- *cobra.Command: The settings command.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.